.. -*- coding: utf-8 -*-

Changes
-------

0.6 (2016-02-23)
~~~~~~~~~~~~~~~~

- Promote the changes logger to the top level


0.5 (2016-02-21)
~~~~~~~~~~~~~~~~

- Handle the case when all preferred activities are removed


0.4 (2016-02-20)
~~~~~~~~~~~~~~~~

- Add person's preferred activities

- Fix SQLAlchemy description of table tasks


0.3 (2016-02-17)
~~~~~~~~~~~~~~~~

- Dump facility, usable to produce a YAML archive compatible with
  metapensiero.sqlalchemy.dbloady


0.2 (2016-02-16)
~~~~~~~~~~~~~~~~

- Stable enough for the first demo


0.1 (unreleased)
~~~~~~~~~~~~~~~~

- Initial effort
